==> geonkick_2.3.8.orig.tar.gz: geonkick-2.3.8/src/kit_widget.h <==
/**
 * File name: kit_widget.h
 * Project: Geonkick (A percussion synthesizer)
 *
 * Copyright (C) 2020 Iurie Nistor <http://iuriepage.wordpress.com>
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef KIT_WIDGET_H
#define KIT_WIDGET_H

#include "geonkick_widget.h"
#include "file_dialog.h"

#include "RkPainter.h"

class RkLineEdit;
class RkButton;
class KitModel;
class RkContainer;
class PercussionModel;
class KitPercussionView;

class KitWidget: public GeonkickWidget
{
 public:
        using PercussionIndex = int;
        KitWidget(GeonkickWidget *parent, KitModel *model);
        KitModel* getModel() const;

 protected:
        void updateView();
        void addPercussion(PercussionModel *model);
        void updatePercussion(PercussionIndex index, PercussionModel *model);
        void removePercussion(PercussionIndex index);
        void copyPercussion(int index);
        void showFileDialog(FileDialog::Type type);
        void openKit(const std::string &file);
        void saveKit(const std::string &file);
        void keyPressEvent(RkKeyEvent *event);

 private:
        KitModel *kitModel;
        RkButton *addButton;
        RkButton *openKitButton;
        RkButton *saveKitButton;
        RkContainer *percussionsContainer;
        std::vector<KitPercussionView*> percussionViewList;
};

class KitKeysView: public GeonkickWidget
{
 public:
        explicit KitKeysView(KitWidget *parent, KitModel *model);

 protected:
        void paintWidget(RkPaintEvent *event) override;

 private:
        KitModel *kitModel;
        int keyWidth;
};

#endif // KIT_WIDGET_H

==> geonkick_2.9.2+dfsg.orig.tar.gz: geonkick-2.9.2/src/kit_widget.h <==
/**
 * File name: kit_widget.h
 * Project: Geonkick (A percussion synthesizer)
 *
 * Copyright (C) 2020 Iurie Nistor <http://iuriepage.wordpress.com>
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef KIT_WIDGET_H
#define KIT_WIDGET_H

#include "geonkick_widget.h"
#include "file_dialog.h"

#include "RkPainter.h"

class RkLineEdit;
class RkButton;
class KitModel;
class RkContainer;
class PercussionModel;
class KitPercussionView;
class RkTimer;

class KitWidget: public GeonkickWidget
{
 public:
        using PercussionIndex = int;
        KitWidget(GeonkickWidget *parent, KitModel *model);
        KitModel* getModel() const;

 protected:
        void updateView();
        void addPercussion(PercussionModel *model);
        void updatePercussion(PercussionIndex index, PercussionModel *model);
        void removePercussion(PercussionIndex index);
        void copyPercussion(int index);
        void showFileDialog(FileDialog::Type type);
        void openKit(const std::string &file);
        void saveKit(const std::string &file);
        void keyPressEvent(RkKeyEvent *event);
        void onUpdateLevelers();
        void exportKitDialog();

 private:
        KitModel *kitModel;
        RkButton *addButton;
        RkButton *openKitButton;
        RkButton *saveKitButton;
        RkContainer *percussionsContainer;
        std::vector<KitPercussionView*> percussionViewList;
        RkTimer *levelersTimer;
};

class KitChannelsView: public GeonkickWidget
{
 public:
        explicit KitChannelsView(KitWidget *parent, KitModel *model);

 protected:
        void paintWidget(RkPaintEvent *event) override;

 private:
        KitModel *kitModel;
        int channelWidth;
};

#endif // KIT_WIDGET_H
